@@ -297,11 +297,11 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
         try:
             self.assertConverted('xls', 'examples/sheets.xls', 'examples/testxls_converted.csv',
                                  ['--sheet', 'data', '--write-sheets', "ʤ,1", '--use-sheet-names'])
-            with open('examples/sheets_ʤ.csv', 'r') as f:
-                with open('examples/testxls_unicode_converted.csv', 'r') as g:
+            with open('examples/sheets_ʤ.csv') as f:
+                with open('examples/testxls_unicode_converted.csv') as g:
                     self.assertEqual(f.read(), g.read())
-            with open('examples/sheets_data.csv', 'r') as f:
-                with open('examples/testxls_converted.csv', 'r') as g:
+            with open('examples/sheets_data.csv') as f:
+                with open('examples/testxls_converted.csv') as g:
                     self.assertEqual(f.read(), g.read())
             self.assertFalse(os.path.exists('examples/sheets_0.csv'))
             self.assertFalse(os.path.exists('examples/sheets_1.csv'))
@@ -316,11 +316,11 @@ class TestIn2CSV(CSVKitTestCase, EmptyFileTests):
         try:
             self.assertConverted('xlsx', 'examples/sheets.xlsx', 'examples/testxlsx_noinference_converted.csv',
                                  ['--no-inference', '--sheet', 'data', '--write-sheets', "ʤ,1", '--use-sheet-names'])
-            with open('examples/sheets_ʤ.csv', 'r') as f:
-                with open('examples/testxlsx_unicode_converted.csv', 'r') as g:
+            with open('examples/sheets_ʤ.csv') as f:
+                with open('examples/testxlsx_unicode_converted.csv') as g:
                     self.assertEqual(f.read(), g.read())
-            with open('examples/sheets_data.csv', 'r') as f:
-                with open('examples/testxlsx_noinference_converted.csv', 'r') as g:
+            with open('examples/sheets_data.csv') as f:
+                with open('examples/testxlsx_noinference_converted.csv') as g:
                     self.assertEqual(f.read(), g.read())
             self.assertFalse(os.path.exists('examples/sheets_0.csv'))
             self.assertFalse(os.path.exists('examples/sheets_1.csv'))
